# Control multiple U2C-1SP4T-63H switches via USB
# Requirements:
#   1: Python.Net (pip install pythonnet)
#   2: Mini-Circuits' DLL API file (mcl_SolidStateSwitch_NET45.dll)
#      https://www.minicircuits.com/softwaredownload/MCL_SolidStateSwitch64_DLL.zip
#      Note: - Windows may block the DLL file after download as a precaution
#            - Right-click on the file, select properties, click "Unblock" (if shown)

import clr # pythonnet
clr.AddReference('C:\Windows\SysWOW64\mcl_SolidStateSwitch_NET45')      # Reference the DLL
from mcl_SolidStateSwitch_NET45 import USB_Digital_Switch

# List the serial numbers of the 6 switches
SN1 = "12004250001"
SN2 = "12004250002"
SN3 = "12004250003"
SN4 = "12004250004"
SN5 = "12004250005"
SN6 = "12004250006"

# Connect the 6 switches by serial number
sw1 = USB_Digital_Switch()  # Create an instance of the switch control class
status1 = sw1.Connect(SN1)  # Connect by serial number (return is a tuple, [0]=0/1 for connection success, [1] = serial number)

sw2 = USB_Digital_Switch()
status2 = sw2.Connect(SN2)

sw3 = USB_Digital_Switch()
status3 = sw3.Connect(SN3)

sw4 = USB_Digital_Switch()
status4 = sw4.Connect(SN4)

sw5 = USB_Digital_Switch()
status5 = sw5.Connect(SN5)

sw6 = USB_Digital_Switch()
status6 = sw6.Connect(SN6)

# Check all connections succeeded
if status1[0] == 0 or status2[0] == 0 or status3[0] == 0 or status4[0] == 0 or status5[0] == 0 or status6[0] == 0:
    print("Can't connect all switches, check USB and serial numbers", status1[0], status2[0], status3[0], status4[0], status5[0], status6[0])
    sys.exit()

# Switching commands

sw1.Send_SCPI(":SP4T:STATE:4", "")              # Set switch 1 (COM<>4)
responses = sw1.Send_SCPI(":SP4T:STATE?", "")   # Read switch state (return is a tuple, [0]=0/1 for function success, [1]=switch command, [2]=switch response)
state1 = str(responses[2])

sw2.Send_SCPI(":SP4T:STATE:4", "")              # Set switch 2 (COM<>4)
responses = sw2.Send_SCPI(":SP4T:STATE?", "")   # Read switch state
state2 = str(responses[2])

sw3.Send_SCPI(":SP4T:STATE:4", "")              # Set switch 3 (COM<>4)
responses = sw3.Send_SCPI(":SP4T:STATE?", "")   # Read switch state
state3 = str(responses[2])

sw4.Send_SCPI(":SP4T:STATE:4", "")              # Set switch 4 (COM<>4)
responses = sw4.Send_SCPI(":SP4T:STATE?", "")   # Read switch state
state4 = str(responses[2])

sw5.Send_SCPI(":SP4T:STATE:4", "")              # Set switch 5 (COM<>4)
responses = sw5.Send_SCPI(":SP4T:STATE?", "")   # Read switch state
state5 = str(responses[2])

sw6.Send_SCPI(":SP4T:STATE:4", "")              # Set switch 6 (COM<>4)
responses = sw6.Send_SCPI(":SP4T:STATE?", "")   # Read switch state
state6 = str(responses[2])

print("Switch states for SW1-6:", state1, state2, state3, state4, state5, state6)

#... Any other switch commands...

# Disconnect all switches at the end of the program
sw1.Disconnect()
sw2.Disconnect()
sw3.Disconnect()
sw4.Disconnect()
sw5.Disconnect()
sw6.Disconnect()
print("Done")
